==> slidy-3.0.1.tar.gz: test/src/modules/package_instalation/infra/repositories/package_install_repository_test.dart <==
import 'package:mocktail/mocktail.dart';
import 'package:slidy/src/core/entities/slidy_process.dart';
import 'package:slidy/src/core/interfaces/pubspec_service.dart';
import 'package:slidy/src/core/models/pubspec.dart';
import 'package:slidy/src/modules/package_instalation/domain/models/package_name.dart';
import 'package:slidy/src/modules/package_instalation/infra/datasources/get_package_version.dart';
import 'package:slidy/src/modules/package_instalation/infra/repositories/package_instalation_repository.dart';
import 'package:test/test.dart';

class PubspecServiceMock extends Mock implements PubspecService {}

class GetPackageVersionMock extends Mock implements GetPackageVersion {}

void main() {
  setUpAll(() {
    registerFallbackValue<Line>(Line(name: '', value: null));
  });
  final pubspecService = PubspecServiceMock();
  final client = GetPackageVersionMock();

  final service = PackageInstalationRepositoryImpl(pubspec: pubspecService, client: client);

  test('should install package', () async {
    when(() => pubspecService.add(any())).thenAnswer((_) async => true);
    when(() => client.fetch(any())).thenAnswer((_) async => '1.0.0');
    final result = await service.install(PackageName('package'));
    expect(result.right, isA<SlidyProccess>());
  });

  test('should install package with version', () async {
    when(() => pubspecService.add(any())).thenAnswer((_) async => true);
    final result = await service.install(PackageName('package@1.0.2'));
    expect(result.right, isA<SlidyProccess>());
  });

  test('should uninstall package', () async {
    when(() => pubspecService.replace(any())).thenAnswer((_) async => true);
    when(() => pubspecService.getLine(any())).thenAnswer((_) async => Line(name: 'dependencies', value: LineMap({'package': Line(name: 'name', value: 'value')})));
    final result = await service.uninstall(PackageName('package'));
    expect(result.right, isA<SlidyProccess>());
  });
}

==> slidy-3.1.0.tar.gz: test/src/modules/package_instalation/infra/repositories/package_install_repository_test.dart <==
import 'package:mocktail/mocktail.dart';
import 'package:slidy/src/core/entities/slidy_process.dart';
import 'package:slidy/src/core/interfaces/yaml_service.dart';
import 'package:slidy/src/modules/package_instalation/domain/models/package_name.dart';
import 'package:slidy/src/modules/package_instalation/infra/datasources/get_package_version.dart';
import 'package:slidy/src/modules/package_instalation/infra/repositories/package_instalation_repository.dart';
import 'package:test/test.dart';

class YamlServiceMock extends Mock implements YamlService {
  @override
  void update(List<String> path, String value) {}
}

class GetPackageVersionMock extends Mock implements GetPackageVersion {}

void main() {
  setUpAll(() {});
  final pubspecService = YamlServiceMock();
  final client = GetPackageVersionMock();

  final service = PackageInstalationRepositoryImpl(pubspec: pubspecService, client: client);

  test('should install package', () async {
    when(() => pubspecService.save()).thenAnswer((_) async => true);
    when(() => client.fetch(any())).thenAnswer((_) async => '1.0.0');
    final result = await service.install(PackageName('package'));
    expect(result.right, isA<SlidyProccess>());
  });

  test('should install package with version', () async {
    when(() => pubspecService.save()).thenAnswer((_) async => true);
    final result = await service.install(PackageName('package@1.0.2'));
    expect(result.right, isA<SlidyProccess>());
  });

  test('should uninstall package', () async {
    when(() => pubspecService.save()).thenAnswer((_) async => true);
    when(() => pubspecService.remove(any())).thenReturn(true);
    final result = await service.uninstall(PackageName('package'));
    expect(result.right, isA<SlidyProccess>());
  });
}
